@@ -4,6 +4,8 @@ class Admin::StockHistoriesController < Admin::BaseController
   before_filter :admin_permission_check_stock
   
   def search
+    addparam = {'retailer_id' => session[:admin_user].retailer_id}
+    params[:condition].merge! addparam unless params[:condition].nil?
     @condition = StockSearchForm.new(params[:condition])
     unless @condition.valid?
       render :action => "index"
@@ -15,7 +17,8 @@ class Admin::StockHistoriesController < Admin::BaseController
       :page => params[:page],
       :per_page => @condition.per_page || 10,
       :conditions => flatten_conditions(@search_list),
-      :order => "id"
+      :include => [:product],
+      :order => "stock_histories.id"
     }
     @stock_histories = StockHistory.paginate(find_options) 
   end
