@@ -3,7 +3,7 @@ require File.dirname(__FILE__) + '/../../spec_helper'
 describe Admin::HomeController do
   fixtures :admin_users, :customers, :order_deliveries
   before(:each) do
-    session[:admin_user] = admin_users(:load_by_admin_user_test_id_1).attributes
+    session[:admin_user] = admin_users(:load_by_admin_user_test_id_1)
   end
 
   #Delete these examples and add some real ones
@@ -16,10 +16,6 @@ describe Admin::HomeController do
     it "ログイン時" do
       get 'index'
       response.should be_success
-      #現在の会員数
-      assigns[:active_customer_num].should == Customer.count(:conditions=>["activate=?", Customer::TOUROKU])
-      #新規受付
-      assigns[:new_orders].should == OrderDelivery.find(:all, :order=>"created_at DESC", :limit=>10)
     end
 
     it 'ログアウト時' do
